# esch

TODO:

1. Default font size to 12pt across sizes
2. Add mesh plot for
3. Known issue is that for animation, fill is determined by first value (and will thus not flip if sign changes during animation).
4. Logic to infer if we have animation is dump. Assumes one dim is 20x times another. Many times that is not the case
